PdfTileCodec enum
How a tile's pixels are encoded into the PDF.
Values
- flateRgb → const PdfTileCodec
-
FlateDecode8-bit RGB - what the real drawing uses. - imageMask → const PdfTileCodec
-
FlateDecode1-bit/ImageMaskstencil - the linework layer. - indexed → const PdfTileCodec
-
FlateDecode8-bit/Indexedpalette. - jpeg → const PdfTileCodec
-
DCTDecode- payload supplied by the caller. - jpeg2000 → const PdfTileCodec
-
JPXDecode- payload supplied by the caller.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PdfTileCodec> - A constant List of the values in this enum, in order of their declaration.